from mkdocs.config import config_options
from mkdocs.plugins import BasePlugin

class TreeTitlePlugin(BasePlugin):
    config_scheme = (
        ('join_string', config_options.Type(str, default=" ")),
    )

    def __init__(self):
        self.enabled = True
        self.total_time = 0

    def on_pre_page(self, page, config, files):
        # skip if pages are not yet included in the mkdocs config file
        if not page.title:
            return page

        join_str = self.config['join_string']

        if page.ancestors:
            tree_titles = [x.title for x in page.ancestors[::-1]] + [page.title]
            page.tree_title = join_str.join(tree_titles)
        else:
            page.tree_title = page.title

        return page




from setuptools import setup, find_packages


setup(
    name='mkdocs-tree-title',
    version='0.1.0',
    description='A MkDocs plugin that adds a tree title for each page. It is composed from the ancestors tree titles and the page title and it is set on the page as tree_title attribute.',
    long_description='',
    keywords='mkdocs',
    url='',
    author='George B',
    author_email='pleat_man@yahoo.com',
    license='MIT',
    python_requires='>=2.7',
    install_requires=[
        'mkdocs>=1.0.4'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    packages=find_packages(),
    entry_points={
        'mkdocs.plugins': [
            'tree-title = mkdocs_tree_title.plugin:TreeTitlePlugin'
        ]
    }
)
